
# Type: located in


holds between a material entity and a material entity or site within which it is located (but of which it is not considered a part)

URI: [biolink:located_in](https://w3id.org/biolink/vocab/located_in)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0001025 |
| **In Subsets:** | | translator_minimal |

